@@ -216,7 +216,7 @@ class ArtellaSequencesManager(object):
 
         status_data = status.get('data')
         if not status_data:
-            LOGGER.error('Impossible to retrieve data from Artella in file: "{}"'.format(sequence_path))
+            LOGGER.info('Impossible to retrieve data from Artella in file: "{}"'.format(sequence_path))
             return
 
         for name, data in status_data.items():
